@@ -8,8 +8,11 @@
 @Desc    : Use gdb by python api when debugging
 '''
 
-
+import os
+from pwncli.utils.exceptions import PwncliTodoException
 from pwnlib import gdb
+import time
+import tempfile
 
 __all__ = [
     "kill_gdb",
@@ -23,6 +26,7 @@ def kill_gdb(gdb_ins):
     """Kill gdb process."""
     if isinstance(gdb_ins, int):
         os.system("kill -9 {}".format(gdb_ins))
+        time.sleep(0.2)
     else:
         gdb_ins.quit()
 
@@ -31,7 +35,8 @@ def execute_cmd_in_gdb(gdb_obj, cmd:str):
     """Execute commands in gdb, split commands by ';' or \\n."""
     cmd = cmd.replace(";", "\n")
     for x in cmd.splitlines():
-        gdb_obj.execute(x)
+        if x:
+            gdb_obj.execute(x)
 
 
 def set_pie_breakpoints(gdb_obj, offset:int):
@@ -41,4 +46,26 @@ def set_pie_breakpoints(gdb_obj, offset:int):
 
 def tele_pie_content(gdb_obj, offset:int, number=10):
     """Telescope content by offset when binary's PIE enabled. Only support for 'pwndbg'."""
-    execute_cmd_in_gdb(gdb_obj, "telescope $rebase({}) {}".format(offset, number))
\ No newline at end of file
+    execute_cmd_in_gdb(gdb_obj, "telescope $rebase({}) {}".format(offset, number))
+
+# TODO
+def define_struct_in_gdb(gdb_obj, struct_name: str, struct_content: str):
+    raise PwncliTodoException()
+    fd, _ = tempfile.mkstemp()
+    f = open(fd, "wt")
+    ws = """#include <stdint.h>
+
+    typedef {{
+        {}
+    }} {};
+    {} _vars;
+    int main()
+    {{
+        return 0;
+    }}
+
+    """.format(struct_content, struct_name, struct_name)
+    print(ws, _)
+    pass
+
+# define_struct_in_gdb(None, "Chunk", "unsigned int id;")
\ No newline at end of file
